/**
 * Database Management API
 * Use the Database Management API to perform tasks such as obtaining performance and resource usage metrics
for a fleet of Managed Databases or a specific Managed Database, creating Managed Database Groups, and
running a SQL job on a Managed Database or Managed Database Group.

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The details of an external database node.
 */
export interface ExternalDbNode {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external DB node.
     */
    "id": string;
    /**
     * The user-friendly name for the external DB node. The name does not have to be unique.
     */
    "displayName": string;
    /**
     * The name of the external DB node.
     */
    "componentName": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external DB system that the DB node is a part of.
     */
    "externalDbSystemId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external connector.
     */
    "externalConnectorId"?: string;
    /**
     * The host name for the DB node.
     */
    "hostName"?: string;
    /**
     * The number of CPU cores available on the DB node. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuCoreCount"?: number;
    /**
     * The total memory in gigabytes (GB) on the DB node. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memorySizeInGBs"?: number;
    /**
     * The additional details of the external DB node defined in {@code {\"key\": \"value\"}} format.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "additionalDetails"?: {
        [key: string]: string;
    };
    /**
     * The current lifecycle state of the external DB node.
     */
    "lifecycleState": ExternalDbNode.LifecycleState;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * Name of the domain.
     */
    "domainName"?: string;
    /**
     * The date and time the external DB node was created.
     */
    "timeCreated": Date;
    /**
     * The date and time the external DB node was last updated.
     */
    "timeUpdated": Date;
}
export declare namespace ExternalDbNode {
    enum LifecycleState {
        Creating = "CREATING",
        NotConnected = "NOT_CONNECTED",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ExternalDbNode): object;
    function getDeserializedJsonObj(obj: ExternalDbNode): object;
}
