/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for the operating system environments in your private data centers through a single management console. For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of the scheduled job.
 */
export interface ScheduledJobSummary {
    /**
     * The OCID of the scheduled job.
     */
    "id": string;
    /**
     * Scheduled job name.
     */
    "displayName": string;
    /**
     * The OCID of the compartment containing the scheduled job.
     */
    "compartmentId": string;
    /**
     * The type of scheduling this scheduled job follows.
     */
    "scheduleType": model.ScheduleTypes;
    /**
     * The time this scheduled job was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time this scheduled job was updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated": Date;
    /**
     * The time/date of the next scheduled execution of this scheduled job.
     */
    "timeNextExecution": Date;
    /**
     * The time/date of the last execution of this scheduled job.
     */
    "timeLastExecution"?: Date;
    /**
     * The list of managed instance OCIDs this scheduled job operates on (mutually exclusive with managedInstanceGroupIds, managedCompartmentIds and lifecycleStageIds).
     */
    "managedInstanceIds"?: Array<string>;
    /**
     * The list of managed instance group OCIDs this scheduled job operates on (mutually exclusive with managedInstances, managedCompartmentIds and lifecycleStageIds).
     */
    "managedInstanceGroupIds"?: Array<string>;
    /**
     * The list of target compartment OCIDs if this scheduled job operates on a compartment level (mutually exclusive with managedInstances, managedInstanceGroupIds and lifecycleStageIds).
     */
    "managedCompartmentIds"?: Array<string>;
    /**
     * The list of target lifecycle stage OCIDs if this scheduled job operates on lifecycle stages (mutually exclusive with managedInstances, managedInstanceGroupIds and managedCompartmentIds).
     */
    "lifecycleStageIds"?: Array<string>;
    /**
     * The list of operations this scheduled job needs to perform (can only support one operation if the operationType is not UPDATE_PACKAGES/UPDATE_ALL/UPDATE_SECURITY/UPDATE_BUGFIX/UPDATE_ENHANCEMENT/UPDATE_OTHER/UPDATE_KSPLICE_USERSPACE/UPDATE_KSPLICE_KERNEL).
     */
    "operations": Array<model.ScheduledJobOperation>;
    /**
     * The current state of the scheduled job.
     */
    "lifecycleState": string;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * true, if the schedule job has its update/deletion capabilities restricted. (Used to track scheduled job for management station syncing).
     */
    "isRestricted"?: boolean;
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ScheduledJobSummary {
    function getJsonObj(obj: ScheduledJobSummary): object;
    function getDeserializedJsonObj(obj: ScheduledJobSummary): object;
}
